==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/QrtzFiredTriggersKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class QrtzFiredTriggersKey extends GenericDPSObject {
    /**
     * QRTZ_FIRED_TRIGGERS.SCHED_NAME
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String schedName;

    /**
     * QRTZ_FIRED_TRIGGERS.ENTRY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String entryId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return QRTZ_FIRED_TRIGGERS.SCHED_NAME
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getSchedName() {
        return schedName;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:40
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * QRTZ_FIRED_TRIGGERS.SCHED_NAME
     *
     * @param schedName
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSchedName(String schedName) {
        this.schedName = schedName == null ? null : schedName.trim();
    }

    /**
     * @return QRTZ_FIRED_TRIGGERS.ENTRY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getEntryId() {
        return entryId;
    }

    /**
     * QRTZ_FIRED_TRIGGERS.ENTRY_ID
     *
     * @param entryId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEntryId(String entryId) {
        this.entryId = entryId == null ? null : entryId.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        QrtzFiredTriggersKey other = (QrtzFiredTriggersKey) that;
        return (this.getSchedName() == null ? other.getSchedName() == null : this.getSchedName().equals(other.getSchedName()))
            && (this.getEntryId() == null ? other.getEntryId() == null : this.getEntryId().equals(other.getEntryId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSchedName() == null) ? 0 : getSchedName().hashCode());
        result = prime * result + ((getEntryId() == null) ? 0 : getEntryId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", schedName=").append(schedName);
        sb.append(", entryId=").append(entryId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/QrtzFiredTriggersKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class QrtzFiredTriggersKey extends GenericDPSObject {
    /**
     * QRTZ_FIRED_TRIGGERS.SCHED_NAME
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String schedName;

    /**
     * QRTZ_FIRED_TRIGGERS.ENTRY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String entryId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return QRTZ_FIRED_TRIGGERS.SCHED_NAME
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getSchedName() {
        return schedName;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:44
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * QRTZ_FIRED_TRIGGERS.SCHED_NAME
     *
     * @param schedName
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSchedName(String schedName) {
        this.schedName = schedName == null ? null : schedName.trim();
    }

    /**
     * @return QRTZ_FIRED_TRIGGERS.ENTRY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getEntryId() {
        return entryId;
    }

    /**
     * QRTZ_FIRED_TRIGGERS.ENTRY_ID
     *
     * @param entryId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEntryId(String entryId) {
        this.entryId = entryId == null ? null : entryId.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        QrtzFiredTriggersKey other = (QrtzFiredTriggersKey) that;
        return (this.getSchedName() == null ? other.getSchedName() == null : this.getSchedName().equals(other.getSchedName()))
            && (this.getEntryId() == null ? other.getEntryId() == null : this.getEntryId().equals(other.getEntryId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSchedName() == null) ? 0 : getSchedName().hashCode());
        result = prime * result + ((getEntryId() == null) ? 0 : getEntryId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", schedName=").append(schedName);
        sb.append(", entryId=").append(entryId);
        sb.append("]");
        return sb.toString();
    }
}
